@@ -1,8 +1,9 @@
 #!/usr/bin/perl
 
-use strict;
+use v5.20;
 use warnings;
 
+use Tickit;
 use Tickit::Widgets qw( VBox CheckButton );
 
 my $vbox = Tickit::Widget::VBox->new( spacing => 1 );
