@@ -1,17 +1,19 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2013-2022 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2013-2023 -- leonerd@leonerd.org.uk
 
 use v5.20;
 use warnings;
 use Object::Pad 0.805;
 
-package Tickit::Style 0.56;
+package Tickit::Style 0.58;
 
 use warnings;
 use experimental 'postderef';
 
+use meta 0.003_001;
+
 use Carp;
 
 use Tickit::Pen;
@@ -241,7 +243,14 @@ sub import
    }
 
    # Import the symbols
-   {
+   use Object::Pad 0.808 ':experimental(mop)';
+   if( my $meta = Object::Pad::MOP::Class->try_for_class( $pkg ) ) {
+      $meta->add_method( $_ => \&{"Tickit::Style::$_"} ) for @EXPORTS;
+      $meta->add_method( _widget_style_type => sub () { $type } );
+   }
+   else {
+      carp "Using legacy Tickit::Style exporter using no strict 'refs'";
+
       no strict 'refs';
       *{"${pkg}::$_"} = \&{"Tickit::Style::$_"} for @EXPORTS;
       *{"${pkg}::_widget_style_type"} = sub () { $type };
@@ -453,7 +462,7 @@ sub load_style_from_DATA
 {
    shift;
    my $pkg = caller;
-   my $fh = do { no strict 'refs'; \*{"${pkg}::DATA"} };
+   my $fh = meta::package->get( $pkg )->get_glob( "DATA" )->reference;
    my $str = do { local $/; <$fh> };
    _load_style( Tickit::Style::Parser->new->from_string( $str ) );
 }
