@@ -7,7 +7,7 @@ use v5.20;
 use warnings;
 use Object::Pad 0.807;
 
-package Tickit::Widget::Box 0.59;
+package Tickit::Widget::Box 0.60;
 class Tickit::Widget::Box :strict(params);
 
 inherit Tickit::ContainerWidget;
@@ -208,46 +208,45 @@ field $_child_cols_max;  method _child_cols_max  :lvalue { $_child_cols_max  }
 field $_child_cols_min;  method _child_cols_min  :lvalue { $_child_cols_min  }
 
 # Because I hate copying code 4 times
-foreach my $dir (qw( lines cols )) {
-   my %subs;
+BEGIN {
+   use Object::Pad 0.800 ':experimental(mop)';
 
-   foreach my $lim (qw( max min )) {
-      my $fieldmeth = "_child_${dir}_${lim}";
-      my $name = "child_${dir}_${lim}";
+   my $meta = Object::Pad::MOP::Class->for_caller;
 
-      $subs{$name} = sub {
-         my $self = shift;
-         my $value = $self->$fieldmeth;
-         if( !defined $value ) {
-            return undef;
-         }
-         elsif( $value =~ m/^(.+)%$/ ) {
-            my $win = $self->window;
-            return $win ? int( $1 * $win->$dir / 100 ) : undef;
-         }
-         else {
-            return $value;
-         }
-      };
+   foreach my $dir (qw( lines cols )) {
+      foreach my $lim (qw( max min )) {
+         my $fieldmeth = "_child_${dir}_${lim}";
+         my $name = "child_${dir}_${lim}";
 
-      $subs{"set_$name"} = sub {
-         my $self = shift;
-         ( $self->$fieldmeth ) = @_;
-         $self->resized;
-      };
+         $meta->add_method( $name => method {
+            my $value = $self->$fieldmeth;
+            if( !defined $value ) {
+               return undef;
+            }
+            elsif( $value =~ m/^(.+)%$/ ) {
+               my $win = $self->window;
+               return $win ? int( $1 * $win->$dir / 100 ) : undef;
+            }
+            else {
+               return $value;
+            }
+         } );
+
+         $meta->add_method( "set_$name" => method {
+            ( $self->$fieldmeth ) = @_;
+            $self->resized;
+         } );
+      }
+
+      my $set_min = "set_child_${dir}_min";
+      my $set_max = "set_child_${dir}_max";
+
+      $meta->add_method( "set_child_$dir" => method {
+         my ( $value ) = @_;
+         $self->$set_min( $value );
+         $self->$set_max( $value );
+      } );
    }
-
-   my $set_min = "set_child_${dir}_min";
-   my $set_max = "set_child_${dir}_max";
-   $subs{"set_child_$dir"} = sub {
-      my $self = shift;
-      my ( $value ) = @_;
-      $self->$set_min( $value );
-      $self->$set_max( $value );
-   };
-
-   no strict 'refs';
-   *{$_} = $subs{$_} for keys %subs;
 }
 
 use Tickit::WidgetRole::Alignable name =>  "align", dir => "h", reshape => 1;
